@@ -4,6 +4,25 @@ use strict;
 use warnings;
 use Scalar::Util ();
 
+sub parse_processing_instruction {
+  my ($pi) = @_;
+  my ($target, $body) = ($pi =~m/^\s*([^\s]+)(.+)$/s);
+  my %attrs = map {
+    my ($key, $val) = split '=', $_;
+    $key=~s/^\s+//g;
+    if($val=~s/^\\//) {
+      $val=~s/^['"]|['"]$//g; 
+      my $val2 = \$val;
+      $key, $val2;
+    } else {
+      $val=~s/^['"]|['"]$//g;
+      $key, $val;
+    }
+  } grep { $_ } 
+    split(/['"]\s+/, $body);
+  return $target => %attrs;
+}
+
 sub parse_itr_spec {
   my ($spec) = @_;
   my ($key, $data_spec) = split('<-', $spec);
@@ -173,6 +192,26 @@ Contains utility functions for L<Template::Pure>
 
 This package contains the following functions:
 
+=head2 parse_processing_instruction ($pi)
+
+Given a processing instruction, parse it into a $target and %attrs such that:
+
+    <?pure-include id='ddd'
+      pure:mode='append|prepend|replace'
+      pure:target='node|content'
+      pure:src='include' ?>
+
+Is parsed into:
+
+    "pure-include" => {
+      id => "ddd",
+      "pure:mode" => "append|prepend|replace",
+      "pure:src" => "include",
+      "pure:target" => "node|content"
+    }
+
+and returned.
+
 =head2 parse_itr_spec ($spec)
 
 Used to parse a string when we are specifying an iterator. For example
